QScintilla/Editor.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 3778
0c5bc18da740
--- a/QScintilla/Editor.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/QScintilla/Editor.py	Sat Jul 05 12:13:23 2014 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the editor component of the eric5 IDE.
+Module implementing the editor component of the eric6 IDE.
 """
 from __future__ import unicode_literals
 try:
@@ -42,7 +42,7 @@
 
 class Editor(QsciScintillaCompat):
     """
     Class implementing the editor component of the eric5 IDE.
     
     @signal modificationStatusChanged(bool, QsciScintillaCompat) emitted when
         the modification status has changed
@@ -6105,7 +6105,7 @@
             else:
                 msg = self.tr(
                     """<p>The file <b>{0}</b> has been changed while it"""
                     """ was opened in eric5. Reread it?</p>""")\
                     .format(self.fileName)
                 yesDefault = True
                 if self.isModified():
@@ -42,7 +42,7 @@
 class Editor(QsciScintillaCompat):
     """
-    Class implementing the editor component of the eric5 IDE.
+    Class implementing the editor component of the eric6 IDE.
     
     @signal modificationStatusChanged(bool, QsciScintillaCompat) emitted when
@@ -6105,7 +6105,7 @@
                 msg = self.tr(
                     """<p>The file <b>{0}</b> has been changed while it"""
-                    """ was opened in eric5. Reread it?</p>""")\
+                    """ was opened in eric6. Reread it?</p>""")\
                     .format(self.fileName)
                 yesDefault = True

eric ide

mercurial